#include "stdafx.h"

//char * g_szQUBIOSettingsTitle = "QUBIO Settings";

class CVwQUBIOSettings : public CDialog { 
	public : 
		//-- Dialog controls
		CDlgEdit m_edtConfigName;
		CDlgEdit m_edtAcqFileName;
		CDlgEdit m_edtBufferSize;
		CDlgEdit m_edtIORate;
		CDlgEdit m_edtDataNotes;
		CDlgCheck m_chkScrollView;
		CDlgCheck m_chkTimeSep;

		CDlgCheck m_chkApplyGain;
		CDlgEdit m_edtGainTableName;
		CDlgEdit m_edtGainSource;
		CDlgEdit m_edtGainApply;

		CDlgCheck m_chkApplyFeedback;
		CDlgEdit m_edtFeedbackName;
		CDlgEdit m_edtFeedbackSource;
		CDlgEdit m_edtFeedbackApply;

		CDlgCheck m_chkRecordDigout;
		CDlgCheck m_chkAutoNewData;
						
		//-- Initialize controls - fill hdw list and set controls to empty values or passed setup
		void InitializeControls( ) { 
			//-- set control handles
			m_edtConfigName.SetHandle( GetDlgItem( m_hDlg, IDC_EDTCONFIGNAME ), "Set the default configuration name to be used for new sessions" );
			m_edtAcqFileName.SetHandle( GetDlgItem( m_hDlg, IDC_EDTACQFILENAME ), "Set the default acquisition file name to be used for new sessions including date/time specifiers." );
			m_edtBufferSize.SetHandle( GetDlgItem( m_hDlg, IDC_EDTBUFSIZE ), "Default acquisition buffer size in samples per channel." );
			m_edtIORate.SetHandle( GetDlgItem( m_hDlg, IDC_EDTIORATE ), "Default acquisition/generation rate in samples per channel per second." );
			m_edtDataNotes.SetHandle( GetDlgItem( m_hDlg, IDC_EDTDATANOTES ), "List of data notes to be added to the acquisition file on demand." );
			m_chkScrollView.SetHandle( GetDlgItem( m_hDlg, IDC_CHKSCROLLVIEW ), "Determines whether new sessions are initially in scrolling(chart) or paging(scope) display mode.");
			m_chkTimeSep.SetHandle( GetDlgItem( m_hDlg, IDC_CHKTIMESEP ), "Determines whether time separator lines are drawn in chart.");
			
			m_chkApplyGain.SetHandle( GetDlgItem( m_hDlg, IDC_CHKAPPLYGAIN ), "Apply gain table multiplier");
			m_edtGainTableName.SetHandle( GetDlgItem( m_hDlg, IDC_EDTTABLENAME  ), "Default gain table");
			m_edtGainSource.SetHandle( GetDlgItem( m_hDlg, IDC_EDTGAINSOURCE ), "Acquisition channel which provides gain table index");
			m_edtGainApply.SetHandle( GetDlgItem( m_hDlg, IDC_EDTGAINAPPLY ), "Acquisition channel to which gain multiplier is applied");

			m_chkApplyFeedback.SetHandle( GetDlgItem( m_hDlg, IDC_CHKAPPLY_FEEDBACK ), "Apply feedback calculation");
			m_edtFeedbackName.SetHandle( GetDlgItem( m_hDlg, IDC_EDTFEEDBACKNAME  ), "Default feedback configuration");
			m_edtFeedbackSource.SetHandle( GetDlgItem( m_hDlg, IDC_EDTFEEDBACKSOURCE ), "Acquisition channel which provides feedback for error calculation");
			m_edtFeedbackApply.SetHandle( GetDlgItem( m_hDlg, IDC_EDTFEEDBACKAPPLY ), "Generation channel to output feedback computed value");

			m_chkRecordDigout.SetHandle( GetDlgItem( m_hDlg, IDC_CHK_RECORDDIGOUT ), "Toggle creation of a simulated data trace for digital outputs in the recorded file.");
			m_chkAutoNewData.SetHandle( GetDlgItem( m_hDlg, IDC_CHK_AUTONEWDATA ), "Generates a new data file name each time you open a Session");

			//-- Limit text lengths 
			m_edtConfigName.SetTextLimit(CONFIG_NAME_LENGTH);
			m_edtAcqFileName.SetTextLimit(_MAX_PATH);
			m_edtBufferSize.SetTextLimit(CFGSESSION_BUFSIZEMAXLEN);
			m_edtIORate.SetTextLimit(CFGSESSION_RATEMAXLEN);
			}

		//-- fill in control data 			
		void Setup( CQUBIOSettings * pSet ) { 
			m_edtConfigName.SetText( pSet->m_cConfigName.Buffer() );
			m_edtAcqFileName.SetText( pSet->m_cAcqFileName.Buffer() );
			m_edtBufferSize.SetTextInt( pSet->m_iBufferSize );
			m_edtIORate.SetTextInt( pSet->m_iIORate );
			m_edtDataNotes.SetText( pSet->m_cDataNotes.Buffer() );
			m_chkScrollView.SetCheck( pSet->m_bScrollView );
			m_chkTimeSep.SetCheck( pSet->m_bTimeSep );

			m_chkApplyGain.SetCheck( pSet->m_bGainTable );
			m_edtGainTableName.SetText( pSet->m_cGainTable.ConstBuffer() );
			m_edtGainSource.SetTextInt( pSet->m_iGainTableSource );
			m_edtGainApply.SetTextInt( pSet->m_iGainTableApply );
			
			m_chkApplyFeedback.SetCheck( pSet->m_bDefaultFeedback );
			m_edtFeedbackName.SetText( pSet->m_cFeedbackName.ConstBuffer() );
			m_edtFeedbackSource.SetTextInt( pSet->m_iFeedbackSource );
			m_edtFeedbackApply.SetTextInt( pSet->m_iFeedbackApply );

			m_chkRecordDigout.SetCheck( pSet->m_bRecordDigout );
			m_chkAutoNewData.SetCheck( pSet->m_bAutoNewData );
			}
		
		void Teardown( CQUBIOSettings * pSet ) { 
			m_edtConfigName.GetText( &pSet->m_cConfigName );
			m_edtAcqFileName.GetText( &pSet->m_cAcqFileName );
			pSet->m_iBufferSize = m_edtBufferSize.GetTextInt();
			pSet->m_iIORate = m_edtIORate.GetTextInt();
			m_edtDataNotes.GetText( &pSet->m_cDataNotes );
			pSet->m_bScrollView = m_chkScrollView.GetCheck(  );
			pSet->m_bTimeSep = m_chkTimeSep.GetCheck(  );

			pSet->m_bGainTable=m_chkApplyGain.GetCheck();
			m_edtGainTableName.GetText( &pSet->m_cGainTable );
			pSet->m_iGainTableSource=m_edtGainSource.GetTextInt();
			pSet->m_iGainTableApply=m_edtGainApply.GetTextInt();

			pSet->m_bDefaultFeedback = m_chkApplyFeedback.GetCheck(  );
			m_edtFeedbackName.GetText( &pSet->m_cFeedbackName );
			pSet->m_iFeedbackSource = m_edtFeedbackSource.GetTextInt();
			pSet->m_iFeedbackApply = m_edtFeedbackApply.GetTextInt();

			pSet->m_bRecordDigout = m_chkRecordDigout.GetCheck( );
			pSet->m_bAutoNewData = m_chkAutoNewData.GetCheck( );
			}

		//-----------------------------------------------------------------------------
		// Events and messages 

		//-- [OK]
		void OnBtnOK() { 
			Teardown( &g_oCfgs.m_oSettings );

			//save to file... 
			g_oCfgs.SaveFile( );
			
			// accept changes 
			EndDialog( m_hDlg, IDOK );
			}
			
		//-- [Cancel]
		void OnBtnCancel() { 
			EndDialog( m_hDlg, IDCANCEL );
			}
						
					
	};

CVwQUBIOSettings * g_pVwQUBIOSettings;		// Modal - one and only instance
	
//-----------------------------------------------------------------------------
// Message Pump
BOOL CALLBACK QUBIOSettingsDlgProc(HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam){ 
	int wmId, wmEvent;
	switch( iMsg ) { 
		//----- DIALOG INIT -  Control Initialization
		case WM_INITDIALOG :		
			g_pVwQUBIOSettings = new CVwQUBIOSettings;
			g_pVwQUBIOSettings->m_hDlg=hDlg;			
			g_pVwQUBIOSettings->InitializeControls();
			g_pVwQUBIOSettings->Setup( (CQUBIOSettings *)lParam );
			return TRUE;

		//----- MENU and CONTROL Commands
		case WM_COMMAND : 
			wmId    = LOWORD(wParam); 
			wmEvent = HIWORD(wParam); 
			switch( wmId ) { 
				case IDCANCEL :						//-- [Cancel]
					g_pVwQUBIOSettings->OnBtnCancel();
					break;
				case IDOK :							//-- [OK]
					g_pVwQUBIOSettings->OnBtnOK();
					break;
				}
			return TRUE;

		case WM_PAINT :
			//PAINTSTRUCT ps; 
			//HDC hdc = BeginPaint(hDlg, &ps); 
			//...extra drawing... 
			//EndPaint(hDlg, &ps); 
			return false;

		case WM_DESTROY : 
			delete g_pVwQUBIOSettings;
			return TRUE;
			
		default : 
			break;
		}
	return FALSE;
	} 

